==> qtjambi-qt3drender-6.3.3-sources.jar: io/qt/qt3d/render/QDirectionalLight.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulate a Directional Light object in a Qt 3D scene</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html">Qt3DRender::QDirectionalLight</a></p>
 */
public class QDirectionalLight extends io.qt.qt3d.render.QAbstractLight
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDirectionalLight.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html#worldDirection-prop">Qt3DRender::QDirectionalLight::worldDirectionChanged(QVector3D)</a></p>
     */
    @io.qt.QtPropertyNotify(name="worldDirection")
    public final Signal1<io.qt.gui.QVector3D> worldDirectionChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QDirectionalLight(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QDirectionalLight() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html#QDirectionalLight">Qt3DRender::QDirectionalLight::QDirectionalLight(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QDirectionalLight(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDirectionalLight instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html#worldDirection-prop">Qt3DRender::QDirectionalLight::setWorldDirection(QVector3D)</a></p>
     */
    @io.qt.QtPropertyWriter(name="worldDirection")
    public final void setWorldDirection(io.qt.gui.QVector3D worldDirection){
        setWorldDirection_native_cref_QVector3D(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(worldDirection));
    }
    
    private native void setWorldDirection_native_cref_QVector3D(long __this__nativeId, long worldDirection);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html#worldDirection-prop">Qt3DRender::QDirectionalLight::worldDirection()const</a></p>
     */
    @io.qt.QtPropertyReader(name="worldDirection")
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D worldDirection(){
        return worldDirection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D worldDirection_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDirectionalLight(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDirectionalLight(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDirectionalLight instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.2-sources.jar: io/qt/qt3d/render/QDirectionalLight.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulate a Directional Light object in a Qt 3D scene</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html">Qt3DRender::QDirectionalLight</a></p>
 */
public class QDirectionalLight extends io.qt.qt3d.render.QAbstractLight
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDirectionalLight.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html#worldDirection-prop">Qt3DRender::QDirectionalLight::worldDirectionChanged(QVector3D)</a></p>
     */
    @io.qt.QtPropertyNotify(name="worldDirection")
    public final Signal1<io.qt.gui.QVector3D> worldDirectionChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QDirectionalLight(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QDirectionalLight() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html#QDirectionalLight">Qt3DRender::QDirectionalLight::QDirectionalLight(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QDirectionalLight(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDirectionalLight instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html#worldDirection-prop">Qt3DRender::QDirectionalLight::setWorldDirection(QVector3D)</a></p>
     */
    @io.qt.QtPropertyWriter(name="worldDirection")
    public final void setWorldDirection(io.qt.gui.QVector3D worldDirection){
        setWorldDirection_native_cref_QVector3D(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(worldDirection));
    }
    
    private native void setWorldDirection_native_cref_QVector3D(long __this__nativeId, long worldDirection);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdirectionallight.html#worldDirection-prop">Qt3DRender::QDirectionalLight::worldDirection()const</a></p>
     */
    @io.qt.QtPropertyReader(name="worldDirection")
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D worldDirection(){
        return worldDirection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D worldDirection_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDirectionalLight(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDirectionalLight(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDirectionalLight instance, QDeclarativeConstructor constructor);
    
}
